@@ -7,12 +7,53 @@ import sys
 import numpy as np
 from numba import njit as jit, prange
 from numpy import cos, cross, sin, sqrt
-from numpy.linalg import norm
 
+from poliastro._math.linalg import norm
 from poliastro.core.angles import E_to_nu, F_to_nu
 from poliastro.core.util import rotation_matrix
 
 
+@jit
+def eccentricity_vector(k, r, v):
+    r"""Eccentricity vector.
+
+    .. math::
+
+       \vec{e} = \frac{1}{\mu} \left(
+           \left( v^{2} - \frac{\mu}{r}\right ) \vec{r}  - (\vec{r} \cdot \vec{v})\vec{v}
+       \right)
+
+    Parameters
+    ----------
+    k : float
+        Standard gravitational parameter (km^3 / s^2).
+    r : numpy.ndarray
+        Position vector (km)
+    v : numpy.ndarray
+        Velocity vector (km / s)
+    """
+    return ((v @ v - k / norm(r)) * r - (r @ v) * v) / k
+
+
+@jit
+def circular_velocity(k, a):
+    r"""Compute circular velocity for a given body given thegravitational parameter and the semimajor axis.
+
+    .. math::
+
+       v = \sqrt{\frac{\mu}{a}}
+
+    Parameters
+    ----------
+    k : float
+        Gravitational Parameter
+    a : float
+        Semimajor Axis
+
+    """
+    return np.sqrt(k / a)
+
+
 @jit
 def rv_pqw(k, p, ecc, nu):
     r"""Returns r and v vectors in perifocal frame.
@@ -25,15 +66,14 @@ def rv_pqw(k, p, ecc, nu):
         Semi-latus rectum or parameter (km).
     ecc : float
         Eccentricity.
-    nu: float
+    nu : float
         True anomaly (rad).
 
     Returns
     -------
-
-    r: ndarray
+    r: numpy.ndarray
         Position. Dimension 3 vector
-    v: ndarray
+    v: numpy.ndarray
         Velocity. Dimension 3 vector
 
     Notes
@@ -111,14 +151,13 @@ def coe2rv(k, p, ecc, inc, raan, argp, nu):
 
     Returns
     -------
-    r_ijk: np.array
+    r_ijk: numpy.ndarray
         Position vector in basis ijk.
-    v_ijk: np.array
+    v_ijk: numpy.ndarray
         Velocity vector in basis ijk.
 
     Notes
     -----
-
     .. math::
         \begin{align}
             \vec{r}_{IJK} &= [ROT3(-\Omega)][ROT1(-i)][ROT3(-\omega)]\vec{r}_{PQW}
@@ -165,34 +204,31 @@ def coe2rv_many(k, p, ecc, inc, raan, argp, nu):
 
 @jit
 def coe2mee(p, ecc, inc, raan, argp, nu):
-    r"""Converts from classical orbital elements to modified equinoctial
-    orbital elements.
+    r"""Converts from classical orbital elements to modified equinoctial orbital elements.
 
-    The definition of the modified equinoctial orbital elements is taken from
-    [Walker, 1985].
+    The definition of the modified equinoctial orbital elements is taken from [Walker, 1985].
 
     The modified equinoctial orbital elements are a set of orbital elements that are useful for
     trajectory analysis and optimization. They are valid for circular, elliptic, and hyperbolic
     orbits. These direct modified equinoctial equations exhibit no singularity for zero
-    eccentricity and orbital inclinations equal to 0 and 90 degrees. However, two of the
-    components are singular for an orbital inclination of 180 degrees.
+    eccentricity and orbital inclinations equal to 0 and 90 degrees. However, the h and k
+    components are singular for an orbital inclination of 180 degrees since the retrograde factor
+    is not yet supported.
 
     Parameters
     ----------
-    k : float
-        Standard gravitational parameter (km^3 / s^2).
     p : float
         Semi-latus rectum or parameter (km).
     ecc : float
         Eccentricity.
     inc : float
         Inclination (rad).
-    omega : float
+    raan : float
         Longitude of ascending node (rad).
     argp : float
         Argument of perigee (rad).
     nu : float
-       True anomaly (rad).
+        True anomaly (rad).
 
     Returns
     -------
@@ -224,10 +260,14 @@ def coe2mee(p, ecc, inc, raan, argp, nu):
         \end{align}
 
     """
+    if inc == np.pi:
+        raise ValueError(
+            "Cannot compute modified equinoctial set for 180 degrees orbit inclination due to `h` and `k` singularity."
+        )
+
     lonper = raan + argp
     f = ecc * np.cos(lonper)
     g = ecc * np.sin(lonper)
-    # TODO: Check polar case (see [Walker, 1985])
     h = np.tan(inc / 2) * np.cos(raan)
     k = np.tan(inc / 2) * np.sin(raan)
     L = lonper + nu
@@ -242,9 +282,9 @@ def rv2coe(k, r, v, tol=1e-8):
     ----------
     k : float
         Standard gravitational parameter (km^3 / s^2)
-    r : array
+    r : numpy.ndarray
         Position vector (km)
-    v : array
+    v : numpy.ndarray
         Velocity vector (km / s)
     tol : float, optional
         Tolerance for eccentricity and inclination checks, default to 1e-8
@@ -342,9 +382,9 @@ def rv2coe(k, r, v, tol=1e-8):
 
     h = cross(r, v)
     n = cross([0, 0, 1], h)
-    e = ((v.dot(v) - k / (norm(r))) * r - r.dot(v) * v) / k
+    e = ((v @ v - k / norm(r)) * r - (r @ v) * v) / k
     ecc = norm(e)
-    p = h.dot(h) / k
+    p = (h @ h) / k
     inc = np.arccos(h[2] / norm(h))
 
     circular = ecc < tol
@@ -353,12 +393,12 @@ def rv2coe(k, r, v, tol=1e-8):
     if equatorial and not circular:
         raan = 0
         argp = np.arctan2(e[1], e[0]) % (2 * np.pi)  # Longitude of periapsis
-        nu = np.arctan2(h.dot(cross(e, r)) / norm(h), r.dot(e))
+        nu = np.arctan2((h @ cross(e, r)) / norm(h), r @ e)
     elif not equatorial and circular:
         raan = np.arctan2(n[1], n[0]) % (2 * np.pi)
         argp = 0
         # Argument of latitude
-        nu = np.arctan2(r.dot(cross(h, n)) / norm(h), r.dot(n))
+        nu = np.arctan2((r @ cross(h, n)) / norm(h), r @ n)
     elif equatorial and circular:
         raan = 0
         argp = 0
@@ -367,17 +407,17 @@ def rv2coe(k, r, v, tol=1e-8):
         a = p / (1 - (ecc**2))
         ka = k * a
         if a > 0:
-            e_se = r.dot(v) / sqrt(ka)
-            e_ce = norm(r) * v.dot(v) / k - 1
+            e_se = (r @ v) / sqrt(ka)
+            e_ce = norm(r) * (v @ v) / k - 1
             nu = E_to_nu(np.arctan2(e_se, e_ce), ecc)
         else:
-            e_sh = r.dot(v) / sqrt(-ka)
+            e_sh = (r @ v) / sqrt(-ka)
             e_ch = norm(r) * (norm(v) ** 2) / k - 1
             nu = F_to_nu(np.log((e_ch + e_sh) / (e_ch - e_sh)) / 2, ecc)
 
         raan = np.arctan2(n[1], n[0]) % (2 * np.pi)
-        px = r.dot(n)
-        py = r.dot(cross(h, n)) / norm(h)
+        px = r @ n
+        py = (r @ cross(h, n)) / norm(h)
         argp = (np.arctan2(py, px) - nu) % (2 * np.pi)
 
     nu = (nu + np.pi) % (2 * np.pi) - np.pi
@@ -406,17 +446,17 @@ def mee2coe(p, f, g, h, k, L):
 
     Parameters
     ----------
-    p: float
+    p : float
         Semi-latus rectum
-    f: float
+    f : float
         Equinoctial parameter f
-    g: float
+    g : float
         Equinoctial parameter g
-    h: float
+    h : float
         Equinoctial parameter h
-    k: float
+    k : float
         Equinoctial parameter k
-    L: float
+    L : float
         Longitude
 
     Returns
@@ -434,7 +474,7 @@ def mee2coe(p, f, g, h, k, L):
     nu: float
         True anomaly
 
-    Note
+    Notes
     -----
     The conversion is always safe because arctan2 works also for 0, 0
     arguments.
@@ -447,3 +487,78 @@ def mee2coe(p, f, g, h, k, L):
     argp = (lonper - raan) % (2 * np.pi)
     nu = (L - lonper) % (2 * np.pi)
     return p, ecc, inc, raan, argp, nu
+
+
+@jit
+def mee2rv(p, f, g, h, k, L):
+    """Calculates position and velocity vector from modified equinoctial elements.
+
+    Parameters
+    ----------
+    p: float
+        Semi-latus rectum
+    f: float
+        Equinoctial parameter f
+    g: float
+        Equinoctial parameter g
+    h: float
+        Equinoctial parameter h
+    k: float
+        Equinoctial parameter k
+    L: float
+        Longitude
+
+    Returns
+    -------
+    r: numpy.ndarray
+        Position vector.
+    v: numpy.ndarray
+        Velocity vector.
+
+    Note
+    ----
+    The definition of `r` and `v` is taken from
+    https://spsweb.fltops.jpl.nasa.gov/portaldataops/mpg/MPG_Docs/Source%20Docs/EquinoctalElements-modified.pdf,
+    Equation 3a and 3b.
+
+    """
+    w = 1 + f * np.cos(L) + g * np.sin(L)
+    r = p / w
+    s2 = 1 + h**2 + k**2
+    alpha2 = h**2 - k**2
+
+    rx = (r / s2)(np.cos(L) + alpha2**2 * np.cos(L) + 2 * h * k * np.sin(L))
+    ry = (r / s2)(np.sin(L) - alpha2**2 * np.sin(L) + 2 * h * k * np.cos(L))
+    rz = (2 * r / s2)(h * np.sin(L) - k * np.cos(L))
+
+    vx = (
+        (-1 / s2)
+        * (np.sqrt(k / p))
+        * (
+            np.sin(L)
+            + alpha2 * np.sin(L)
+            - 2 * h * k * np.cos(L)
+            + g
+            - 2 * f * h * k
+            + alpha2 * g
+        )
+    )
+    vy = (
+        (-1 / s2)
+        * (np.sqrt(k / p))
+        * (
+            -np.cos(L)
+            + alpha2 * np.cos(L)
+            + 2 * h * k * np.sin(L)
+            - f
+            + 2 * g * h * k
+            + alpha2 * f
+        )
+    )
+    vz = (
+        (2 / s2)
+        * (np.sqrt(k / p))
+        * (h * np.cos(L) + k * np.sin(L) + f * h + g * k)
+    )
+
+    return np.array([rx, ry, rz]), np.array([vx, vy, vz])
