@@ -1,9 +1,9 @@
 import numpy as np
 from numba import njit as jit
 from numpy import cross
-from numpy.linalg import norm
 
-from poliastro.core.util import circular_velocity
+from poliastro._math.linalg import norm
+from poliastro.core.elements import circular_velocity
 
 
 @jit
@@ -76,12 +76,9 @@ def change_a_inc(k, a_0, a_f, inc_0, inc_f, f):
     Returns
     -------
     a_d : function
-
-    delta_V : numpy.array
-
+    delta_V : numpy.ndarray
     t_f : float
 
-
     Notes
     -----
     Edelbaum theory, reformulated by Kéchichian.
