@@ -1,10 +1,9 @@
 import numpy as np
 from numba import njit as jit
 from numpy import cross
-from numpy.linalg import norm
 
-from poliastro.core.elements import rv2coe
-from poliastro.core.util import circular_velocity
+from poliastro._math.linalg import norm
+from poliastro.core.elements import circular_velocity, rv2coe
 
 
 @jit
@@ -49,9 +48,7 @@ def change_argp(k, a, ecc, argp_0, argp_f, f):
     Returns
     -------
     a_d : function
-
-    delta_V : numpy.array
-
+    delta_V : numpy.ndarray
     t_f : float
     """
 
