@@ -8,10 +8,13 @@ References
 import numpy as np
 from numba import njit as jit
 from numpy import cross
-from numpy.linalg import norm
 
-from poliastro.core.elements import rv2coe
-from poliastro.core.util import circular_velocity, eccentricity_vector
+from poliastro._math.linalg import norm
+from poliastro.core.elements import (
+    circular_velocity,
+    eccentricity_vector,
+    rv2coe,
+)
 
 
 @jit
