@@ -5,13 +5,14 @@ from astropy import units as u
 from astropy.coordinates import (
     GCRS,
     ITRS,
+    CartesianDifferential,
     CartesianRepresentation,
     SphericalRepresentation,
 )
 
 from poliastro.bodies import Earth
 from poliastro.earth.plotting.utils import EARTH_PALETTE
-from poliastro.twobody.propagation import propagate
+from poliastro.twobody.sampling import EpochsArray
 
 
 class GroundtrackPlotter:
@@ -22,9 +23,9 @@ class GroundtrackPlotter:
 
         Parameters
         ----------
-        fig: ~plotly.graph_objects.Figure
+        fig : ~plotly.graph_objects.Figure
             Figure instance for the canvas
-        color_palette: dict
+        color_palette : dict
             A color palette for background map
 
         """
@@ -54,7 +55,7 @@ class GroundtrackPlotter:
 
         Parameters
         ----------
-        config: dict
+        **config : dict
             A collection of custom values for geo figure
 
         """
@@ -66,7 +67,7 @@ class GroundtrackPlotter:
 
         Parameters
         ----------
-        config: dict
+        **config : dict
             A collection of custom values for figure layout
 
         """
@@ -78,27 +79,33 @@ class GroundtrackPlotter:
 
         self.fig.add_trace(trace)
 
-    def _get_raw_coords(self, ss, t_deltas):
+    def _get_raw_coords(self, orb, t_deltas):
         """Generates raw orbit coordinates for given epochs
 
         Parameters
         ----------
-        ss: ~poliastro.twobody.orbit
+        orb : ~poliastro.twobody.Orbit
             Orbit to be propagated
-        t_deltas: ~astropy.time.DeltaTime
+        t_deltas : ~astropy.time.DeltaTime
             Desired observation time
 
         Returns
         -------
-        raw_xyz: array
-            A collection of raw cartessian position vectors
-        raw_epochs: array
+        raw_xyz : numpy.ndarray
+            A collection of raw cartesian position vectors
+        raw_epochs : numpy.ndarray
             Associated epoch with previously raw coordinates
         """
 
         # Solve for raw coordinates and epochs
-        raw_xyz = propagate(ss, t_deltas)
-        raw_epochs = ss.epoch + t_deltas
+        ephem = orb.to_ephem(EpochsArray(orb.epoch + t_deltas))
+        rr, vv = ephem.rv()
+        raw_xyz = CartesianRepresentation(
+            rr,
+            xyz_axis=-1,
+            differentials=CartesianDifferential(vv, xyz_axis=-1),
+        )
+        raw_epochs = ephem.epochs
 
         return raw_xyz, raw_epochs
 
@@ -107,9 +114,9 @@ class GroundtrackPlotter:
 
         Parameters
         ----------
-        raw_xyz: array
+        raw_xyz : numpy.ndarray
             A collection of rwa position coordinates
-        raw_obstime: array
+        raw_obstime : numpy.ndarray
             Associated observation time
 
         Returns
@@ -129,18 +136,18 @@ class GroundtrackPlotter:
 
         return itrs_xyz
 
-    def _trace_groundtrack(self, ss, t_deltas, label, line_style):
+    def _trace_groundtrack(self, orb, t_deltas, label, line_style):
         """Generates a trace for EarthSatellite's orbit grountrack
 
         Parameters
         ----------
-        ss: ~poliastro.twobody.Orbit
+        orb : ~poliastro.twobody.Orbit
             EarthSatellite's associated Orbit
-        t_deltas: ~astropy.time.DeltaTime
+        t_deltas : ~astropy.time.DeltaTime
             Collection of epochs
-        label: string
+        label : string
             Name for the trace
-        line_style: dict
+        line_style : dict
             Dictionary for customizing groundtrack line trace
 
         Returns
@@ -151,7 +158,7 @@ class GroundtrackPlotter:
         """
 
         # Compute predicted grountrack positions
-        raw_xyz, raw_obstime = self._get_raw_coords(ss, t_deltas)
+        raw_xyz, raw_obstime = self._get_raw_coords(orb, t_deltas)
         itrs_xyz = self._from_raw_to_ITRS(raw_xyz, raw_obstime)
         itrs_latlon = itrs_xyz.represent_as(SphericalRepresentation)
 
@@ -171,11 +178,11 @@ class GroundtrackPlotter:
 
         Parameters
         ----------
-        ss: ~poliastro.twobody.Orbit
+        ss : ~poliastro.twobody.Orbit
             EarthSatellite's orbit
-        label: string
+        label : string
             Label for the orbit
-        marker: dict
+        marker : dict
             Dicitonary holding plotly marker configuration
 
         Returns
@@ -205,20 +212,22 @@ class GroundtrackPlotter:
 
         return trace
 
-    def plot(self, earth_ss, t_span, label, color, line_style={}, marker={}):
-        """Plots desired Earth satellite orbit for a given time span
+    def plot(self, earth_orb, t_span, label, color, line_style={}, marker={}):
+        """Plots desired Earth satellite orbit for a given time span.
 
         Parameters
         ----------
-        earth_ss: ~poliastro.earth.EarthSatellite
+        earth_orb : ~poliastro.earth.EarthSatellite
             Desired Earth's satellite to who's grountrack will be plotted
-        t_span: ~astropy.time.TimeDelta
+        t_span : ~astropy.time.TimeDelta
             A collection of epochs
-        color: string
+        label : str
+            Label for the groundtrack.
+        color : string
             Desired lines and traces color
-        line_style: dict
+        line_style : dict
             Dictionary for customizing groundtrack line trace
-        marker: dict
+        marker : dict
             Dictionary for customizing groundtrack marker trace
 
         Returns
@@ -229,24 +238,24 @@ class GroundtrackPlotter:
         """
 
         # Retrieve basic parameters and check for proper attractor
-        ss = earth_ss.orbit
-        if ss.attractor != Earth:
+        orb = earth_orb.orbit
+        if orb.attractor != Earth:
             raise ValueError(
-                f"Satellite should be orbiting Earth, not {ss.attractor}."
+                f"Satellite should be orbiting Earth, not {orb.attractor}."
             )
         else:
-            t_deltas = t_span - ss.epoch
+            t_deltas = t_span - orb.epoch
 
         # Ensure same line and marker color unless user specifies
         for style in [line_style, marker]:
             style.setdefault("color", color)
 
         # Generate groundtrack trace and add it to figure
-        gnd_trace = self._trace_groundtrack(ss, t_deltas, label, line_style)
+        gnd_trace = self._trace_groundtrack(orb, t_deltas, label, line_style)
         self.add_trace(gnd_trace)
 
         # Generate position trace and add it to figure
-        pos_trace = self._trace_position(ss, label, marker)
+        pos_trace = self._trace_position(orb, label, marker)
         self.add_trace(pos_trace)
 
         # Return figure
