@@ -19,7 +19,13 @@ Taken from Plyades (c) 2012 Helge Eichhorn (MIT License)
 """
 
 molniya = Orbit.from_classical(
-    Earth, 26600 * u.km, 0.75 * u.one, 63.4 * u.deg, 0 * u.deg, 270 * u.deg, 80 * u.deg
+    attractor=Earth,
+    a=26600 * u.km,
+    ecc=0.75 * u.one,
+    inc=63.4 * u.deg,
+    raan=0 * u.deg,
+    argp=270 * u.deg,
+    nu=80 * u.deg,
 )
 """Molniya orbit example"""
 
@@ -27,7 +33,13 @@ _r_a = Earth.R + 35950 * u.km
 _r_p = Earth.R + 250 * u.km
 _a = (_r_a + _r_p) / 2
 soyuz_gto = Orbit.from_classical(
-    Earth, _a, _r_a / _a - 1, 6 * u.deg, 188.5 * u.deg, 178 * u.deg, 0 * u.deg
+    attractor=Earth,
+    a=_a,
+    ecc=_r_a / _a - 1,
+    inc=6 * u.deg,
+    raan=188.5 * u.deg,
+    argp=178 * u.deg,
+    nu=0 * u.deg,
 )
 """Soyuz geostationary transfer orbit (GTO) example
 
@@ -36,13 +48,13 @@ Taken from Soyuz User's Manual, issue 2 revision 0
 """
 
 churi = Orbit.from_classical(
-    Sun,
-    3.46250 * u.AU,
-    0.64 * u.one,
-    7.04 * u.deg,
-    50.1350 * u.deg,
-    12.8007 * u.deg,
-    63.89 * u.deg,
-    time.Time("2015-11-05 12:00", scale="utc"),
+    attractor=Sun,
+    a=3.46250 * u.AU,
+    ecc=0.64 * u.one,
+    inc=7.04 * u.deg,
+    raan=50.1350 * u.deg,
+    argp=12.8007 * u.deg,
+    nu=63.89 * u.deg,
+    epoch=time.Time("2015-11-05 12:00", scale="utc"),
 )
 """Comet 67P/Churyumov–Gerasimenko orbit example"""
