@@ -8,7 +8,9 @@ from poliastro.core.iod import izzo as izzo_fast
 kms = u.km / u.s
 
 
-def lambert(k, r0, r, tof, M=0, numiter=35, rtol=1e-8):
+def lambert(
+    k, r0, r, tof, M=0, prograde=True, lowpath=True, numiter=35, rtol=1e-8
+):
     """Solves the Lambert problem using the Izzo algorithm.
 
     .. versionadded:: 0.5.0
@@ -25,13 +27,18 @@ def lambert(k, r0, r, tof, M=0, numiter=35, rtol=1e-8):
         Time of flight (s).
     M : int, optional
         Number of full revolutions, default to 0.
+    prograde: boolean
+        Controls the desired inclination of the transfer orbit.
+    lowpath: boolean
+        If `True` or `False`, gets the transfer orbit whose vacant focus is
+        below or above the chord line, respectively.
     numiter : int, optional
         Maximum number of iterations, default to 35.
     rtol : float, optional
         Relative tolerance of the algorithm, default to 1e-8.
 
-    Yields
-    ------
+    Returns
+    -------
     v0, v : tuple
         Pair of velocity solutions.
 
@@ -41,7 +48,5 @@ def lambert(k, r0, r, tof, M=0, numiter=35, rtol=1e-8):
     r_ = r.to_value(u.km)
     tof_ = tof.to_value(u.s)
 
-    sols = izzo_fast(k_, r0_, r_, tof_, M, numiter, rtol)
-
-    for v0, v in sols:
-        yield v0 << kms, v << kms
+    v0, v = izzo_fast(k_, r0_, r_, tof_, M, prograde, lowpath, numiter, rtol)
+    return v0 << kms, v << kms
