@@ -33,7 +33,7 @@ class Maneuver:
 
         Parameters
         ----------
-        impulses : list
+        *args : list
             List of pairs (delta_time, delta_velocity)
 
         """
@@ -68,7 +68,7 @@ class Maneuver:
 
         Parameters
         ----------
-        dv: np.array
+        dv : numpy.ndarray
             Velocity components of the impulse.
 
         """
@@ -81,9 +81,9 @@ class Maneuver:
 
         Parameters
         ----------
-        orbit_i: poliastro.twobody.orbit.Orbit
+        orbit_i : poliastro.twobody.orbit.Orbit
             Initial orbit
-        r_f: astropy.unit.Quantity
+        r_f : astropy.unit.Quantity
             Final orbital radius
 
         """
@@ -117,11 +117,11 @@ class Maneuver:
 
         Parameters
         ----------
-        orbit_i: poliastro.twobody.orbit.Orbit
+        orbit_i : poliastro.twobody.orbit.Orbit
             Initial orbit
-        r_b: astropy.unit.Quantity
+        r_b : astropy.unit.Quantity
             Altitude of the intermediate orbit
-        r_f: astropy.unit.Quantity
+        r_f : astropy.unit.Quantity
             Final orbital radius
 
         """
@@ -163,23 +163,21 @@ class Maneuver:
         )
 
     @classmethod
-    def lambert(
-        cls, orbit_i, orbit_f, method=lambert_izzo, short=True, **kwargs
-    ):
+    def lambert(cls, orbit_i, orbit_f, method=lambert_izzo, **kwargs):
         """Computes Lambert maneuver between two different points.
 
         Parameters
         ----------
-        orbit_i: ~poliastro.twobody.Orbit
+        orbit_i : ~poliastro.twobody.Orbit
             Initial orbit
-        orbit_f: ~poliastro.twobody.Orbit
+        orbit_f : ~poliastro.twobody.Orbit
             Final orbit
-        method: function
+        method : function
             Method for solving Lambert's problem
-        short: keyword, boolean
-            Selects between short and long solution
-
+        **kwargs
+            Extra kwargs for Lambert method.
         """
+
         # Get initial algorithm conditions
         k = orbit_i.attractor.k
         r_i = orbit_i.r
@@ -187,12 +185,14 @@ class Maneuver:
 
         # Time of flight is solved by subtracting both orbit epochs
         tof = orbit_f.epoch - orbit_i.epoch
+        if tof.to_value(u.s) < 0:
+            raise ValueError(
+                "Epoch of initial orbit greater than epoch of final orbit, "
+                "causing a negative time of flight"
+            )
 
         # Compute all possible solutions to the Lambert transfer
-        sols = list(method(k, r_i, r_f, tof, **kwargs))
-
-        # Return short or long solution
-        dv_a, dv_b = sols[0] if short else sols[-1]
+        dv_a, dv_b = method(k, r_i, r_f, tof, **kwargs)
 
         return cls(
             (0 * u.s, (dv_a - orbit_i.v).decompose()),
@@ -219,7 +219,7 @@ class Maneuver:
         orbit : Orbit
             Position and velocity of a body with respect to an attractor
             at a given time (epoch).
-        max_delta_r: ~astropy.units.Quantity
+        max_delta_r : ~astropy.units.Quantity
             Maximum satellite’s geocentric distance
 
         Returns
