@@ -6,7 +6,7 @@ from poliastro.core.flybys import compute_flyby as compute_flyby_fast
 @u.quantity_input(
     v_spacecraft=u.km / u.s,
     v_body=u.km / u.s,
-    k=u.km ** 3 / u.s ** 2,
+    k=u.km**3 / u.s**2,
     r_p=u.km,
     theta=u.deg,
 )
@@ -36,10 +36,12 @@ def compute_flyby(v_spacecraft, v_body, k, r_p, theta=0 * u.deg):
     """
     v_spacecraft = v_spacecraft.to_value(u.km / u.s)
     v_body = v_body.to_value(u.km / u.s)
-    k = k.to_value(u.km ** 3 / u.s ** 2)
+    k = k.to_value(u.km**3 / u.s**2)
     r_p = r_p.to_value(u.km)
     theta = theta.to_value(u.rad)
 
-    v_spacecraft_out, delta = compute_flyby_fast(v_spacecraft, v_body, k, r_p, theta)
+    v_spacecraft_out, delta = compute_flyby_fast(
+        v_spacecraft, v_body, k, r_p, theta
+    )
 
     return v_spacecraft_out * u.km / u.s, delta * u.rad
