@@ -3,22 +3,34 @@
 """
 import numpy as np
 from astropy import units as u
+from astropy.coordinates import Angle
 from astropy.time import Time
-from numpy.linalg import norm as norm_np
 
+from poliastro._math.linalg import norm as norm_fast
 from poliastro.core.util import alinspace as alinspace_fast
 
 
-def norm(vec):
+def norm(vec, axis=None):
     """Norm of a Quantity vector that respects units.
 
     Parameters
     ----------
     vec : ~astropy.units.Quantity
         Vector with units.
+    axis : int or None
+        Axis along which to compute the vector norms.
 
     """
-    return norm_np(vec.value) * vec.unit
+    if axis is not None:
+        # axis keyword argument is not yet supported by numba,
+        # see https://github.com/numba/numba/issues/2558
+        from numpy.linalg import norm as norm_np
+
+        result = norm_np(vec.value, axis=axis)
+    else:
+        result = norm_fast(vec.value)
+
+    return result << vec.unit
 
 
 def time_range(
@@ -30,6 +42,8 @@ def time_range(
 
     Parameters
     ----------
+    start : ~astropy.time.Time or ~astropy.units.Quantity
+        Start time.
     periods : int, optional
         Number of periods, default to 50.
     spacing : ~astropy.time.Time or ~astropy.units.Quantity, optional
@@ -86,3 +100,8 @@ def alinspace(start, stop=None, *, num=50, endpoint=True):
         )
         * u.rad
     )
+
+
+@u.quantity_input(angle=u.rad, limit=u.rad)
+def wrap_angle(angle, limit=180 * u.deg):
+    return Angle(angle).wrap_at(limit)
