@@ -16,7 +16,9 @@ try:
 except ImportError:
     pass
 
-pytestmark = pytest.mark.skipif("czml3" not in sys.modules, reason="requires czml3")
+pytestmark = pytest.mark.skipif(
+    "czml3" not in sys.modules, reason="requires czml3"
+)
 
 
 def test_czml_get_document():
@@ -38,9 +40,7 @@ def test_czml_custom_packet():
 
     sample_points = 10
 
-    pr_map_url = (
-        "https://upload.wikimedia.org/wikipedia/commons/c/c4/Earthmap1000x500compac.jpg"
-    )
+    pr_map_url = "https://upload.wikimedia.org/wikipedia/commons/c/c4/Earthmap1000x500compac.jpg"
     scene = False
     expected_packet = """{
     "id": "custom_properties",
@@ -318,7 +318,10 @@ def test_czml_add_orbit():
     extractor = CZMLExtractor(start_epoch, end_epoch, sample_points)
 
     extractor.add_orbit(
-        molniya, rtol=1e-4, label_text="Molniya", label_fill_color=[125, 80, 120, 255]
+        molniya,
+        rtol=1e-4,
+        label_text="Molniya",
+        label_fill_color=[125, 80, 120, 255],
     )
     extractor.add_orbit(iss, rtol=1e-4, label_text="ISS", path_show=False)
 
@@ -458,12 +461,18 @@ def test_czml_add_trajectory(expected_doc_add_trajectory):
     z = u.Quantity([7.0, 8.0, 9.0], u.m)
     positions = CartesianRepresentation(x, y, z)
 
-    time = ["2010-01-01T05:00:00", "2010-01-01T05:00:30", "2010-01-01T05:01:00"]
+    time = [
+        "2010-01-01T05:00:00",
+        "2010-01-01T05:00:30",
+        "2010-01-01T05:01:00",
+    ]
     epochs = Time(time, format="isot")
 
     extractor = CZMLExtractor(start_epoch, end_epoch, sample_points)
 
-    extractor.add_trajectory(positions, epochs, label_text="Test", path_color=color)
+    extractor.add_trajectory(
+        positions, epochs, label_text="Test", path_color=color
+    )
 
     assert repr(extractor.packets) == expected_doc_add_trajectory
 
@@ -485,7 +494,9 @@ def test_czml_raises_error_if_length_of_points_and_epochs_not_same():
     extractor = CZMLExtractor(start_epoch, end_epoch, sample_points)
 
     with pytest.raises(ValueError) as excinfo:
-        extractor.add_trajectory(positions, epochs, label_text="Test", path_color=color)
+        extractor.add_trajectory(
+            positions, epochs, label_text="Test", path_color=color
+        )
     assert "Number of Points and Epochs must be equal." in excinfo.exconly()
 
 
@@ -809,7 +820,9 @@ def test_czml_ground_station():
         label_text="GS test",
     )
 
-    extractor.add_ground_station([0.70930 * u.rad, 0.40046 * u.rad], label_show=False)
+    extractor.add_ground_station(
+        [0.70930 * u.rad, 0.40046 * u.rad], label_show=False
+    )
     assert repr(extractor.packets) == expected_doc
 
 
@@ -902,11 +915,18 @@ def test_czml_add_trajectory_raises_error_for_groundtrack_show():
     z = u.Quantity([7.0, 8.0, 9.0], u.m)
     positions = CartesianRepresentation(x, y, z)
 
-    time = ["2010-01-01T05:00:00", "2010-01-01T05:00:30", "2010-01-01T05:01:00"]
+    time = [
+        "2010-01-01T05:00:00",
+        "2010-01-01T05:00:30",
+        "2010-01-01T05:01:00",
+    ]
     epochs = Time(time, format="isot")
 
     extractor = CZMLExtractor(start_epoch, end_epoch, sample_points)
 
     with pytest.raises(NotImplementedError) as excinfo:
         extractor.add_trajectory(positions, epochs, groundtrack_show=True)
-    assert "Ground tracking for trajectory not implemented yet" in excinfo.exconly()
+    assert (
+        "Ground tracking for trajectory not implemented yet"
+        in excinfo.exconly()
+    )
