@@ -13,21 +13,27 @@ from astropy.tests.helper import assert_quantity_allclose
 from astropy.time import Time
 
 from poliastro.bodies import Earth, Venus
-from poliastro.ephem import Ephem, InterpolationMethods
+from poliastro.ephem import Ephem, SincInterpolator, SplineInterpolator
 from poliastro.frames import Planes
 from poliastro.twobody.orbit import Orbit
 from poliastro.warnings import TimeScaleWarning
 
-AVAILABLE_INTERPOLATION_METHODS = InterpolationMethods.__members__.values()
+AVAILABLE_INTERPOLATORS = [SincInterpolator(), SplineInterpolator()]
 AVAILABLE_PLANES = Planes.__members__.values()
 
 
-def assert_coordinates_allclose(actual, desired, rtol=1e-7, atol_scale=None, **kwargs):
+def assert_coordinates_allclose(
+    actual, desired, rtol=1e-7, atol_scale=None, **kwargs
+):
     if atol_scale is None:
         atol_scale = 0
 
     assert_quantity_allclose(
-        actual.xyz, desired.xyz, rtol, atol=atol_scale * desired.xyz.unit, **kwargs
+        actual.xyz,
+        desired.xyz,
+        rtol,
+        atol=atol_scale * desired.xyz.unit,
+        **kwargs,
     )
     if "s" in desired.differentials:
         assert_quantity_allclose(
@@ -77,31 +83,32 @@ def test_ephem_fails_if_dimensions_are_not_correct(epochs, coordinates):
     with pytest.raises(ValueError) as excinfo:
         Ephem(epochs[0], coordinates, unused_plane)
     assert (
-        "Coordinates and epochs must have dimension 1, got 0 and 1" in excinfo.exconly()
+        "Coordinates and epochs must have dimension 1, got 0 and 1"
+        in excinfo.exconly()
     )
 
 
-@pytest.mark.parametrize("method", AVAILABLE_INTERPOLATION_METHODS)
+@pytest.mark.parametrize("interpolator", AVAILABLE_INTERPOLATORS)
 def test_ephem_sample_no_arguments_returns_exactly_same_input(
-    epochs, coordinates, method
+    epochs, coordinates, interpolator
 ):
     unused_plane = Planes.EARTH_EQUATOR
     ephem = Ephem(coordinates, epochs, unused_plane)
 
-    result_coordinates = ephem.sample(method=method)
+    result_coordinates = ephem.sample(interpolator=interpolator)
 
     # Exactly the same
     assert np.all(result_coordinates == coordinates)
 
 
-@pytest.mark.parametrize("method", AVAILABLE_INTERPOLATION_METHODS)
+@pytest.mark.parametrize("interpolator", AVAILABLE_INTERPOLATORS)
 def test_ephem_sample_scalar_epoch_returns_1_dimensional_coordinates(
-    epochs, coordinates, method
+    epochs, coordinates, interpolator
 ):
     unused_plane = Planes.EARTH_EQUATOR
     ephem = Ephem(coordinates, epochs, unused_plane)
 
-    result_coordinates = ephem.sample(epochs[0], method=method)
+    result_coordinates = ephem.sample(epochs[0], interpolator=interpolator)
 
     # Exactly the same
     assert result_coordinates.ndim == 1
@@ -119,43 +126,49 @@ def test_ephem_str_matches_expected_representation(epochs, coordinates):
     assert repr(ephem) == str(ephem) == expected_str
 
 
-@pytest.mark.parametrize("method", AVAILABLE_INTERPOLATION_METHODS)
+@pytest.mark.parametrize("interpolator", AVAILABLE_INTERPOLATORS)
 def test_ephem_sample_scalar_epoch_and_coordinates_returns_exactly_same_input(
-    epochs, coordinates, method
+    epochs, coordinates, interpolator
 ):
     unused_plane = Planes.EARTH_EQUATOR
     coordinates = coordinates[0].reshape(-1)
     epochs = epochs[0].reshape(-1)
     ephem = Ephem(coordinates, epochs, unused_plane)
 
-    result_coordinates = ephem.sample(epochs[0], method=method)
+    result_coordinates = ephem.sample(epochs[0], interpolator=interpolator)
 
     # Exactly the same
     assert result_coordinates == coordinates
 
 
-@pytest.mark.parametrize("method", AVAILABLE_INTERPOLATION_METHODS)
-def test_ephem_sample_same_epochs_returns_same_input(epochs, coordinates, method):
-    unused_plane = Planes.EARTH_EQUATOR
-    ephem = Ephem(coordinates, epochs, unused_plane)
-
-    result_coordinates = ephem.sample(epochs, method=method)
-
-    # TODO: Should it return exactly the same?
-    assert_coordinates_allclose(result_coordinates, coordinates, atol_scale=1e-17)
-
-
-@pytest.mark.parametrize("method", AVAILABLE_INTERPOLATION_METHODS)
-def test_ephem_sample_existing_epochs_returns_corresponding_input(
-    epochs, coordinates, method
+@pytest.mark.parametrize("interpolator", AVAILABLE_INTERPOLATORS)
+def test_ephem_sample_same_epochs_returns_same_input(
+    epochs, coordinates, interpolator
 ):
     unused_plane = Planes.EARTH_EQUATOR
     ephem = Ephem(coordinates, epochs, unused_plane)
 
-    result_coordinates = ephem.sample(epochs[::2], method=method)
+    result_coordinates = ephem.sample(epochs, interpolator=interpolator)
+
+    # TODO: Should it return exactly the same?
+    assert_coordinates_allclose(
+        result_coordinates, coordinates, atol_scale=1e-17
+    )
+
+
+@pytest.mark.parametrize("interpolator", AVAILABLE_INTERPOLATORS)
+def test_ephem_sample_existing_epochs_returns_corresponding_input(
+    epochs, coordinates, interpolator
+):
+    unused_plane = Planes.EARTH_EQUATOR
+    ephem = Ephem(coordinates, epochs, unused_plane)
+
+    result_coordinates = ephem.sample(epochs[::2], interpolator=interpolator)
 
     # Exactly the same
-    assert_coordinates_allclose(result_coordinates, coordinates[::2], atol_scale=1e-17)
+    assert_coordinates_allclose(
+        result_coordinates, coordinates[::2], atol_scale=1e-17
+    )
 
 
 def test_rv_no_parameters_returns_input_vectors(coordinates, epochs):
@@ -184,7 +197,7 @@ def test_rv_scalar_epoch_returns_scalar_vectors(coordinates, epochs):
     assert_quantity_allclose(v, expected_v)
 
 
-@pytest.mark.parametrize("method", AVAILABLE_INTERPOLATION_METHODS)
+@pytest.mark.parametrize("interpolator", AVAILABLE_INTERPOLATORS)
 @pytest.mark.parametrize(
     "plane, FrameClass, rtol",
     [
@@ -192,9 +205,15 @@ def test_rv_scalar_epoch_returns_scalar_vectors(coordinates, epochs):
         (Planes.EARTH_ECLIPTIC, BarycentricMeanEcliptic, 1e-5),
     ],
 )
-def test_ephem_from_body_has_expected_properties(method, plane, FrameClass, rtol):
+def test_ephem_from_body_has_expected_properties(
+    interpolator, plane, FrameClass, rtol
+):
     epochs = Time(
-        ["2020-03-01 12:00:00", "2020-03-17 00:00:00.000", "2020-04-01 12:00:00.000"],
+        [
+            "2020-03-01 12:00:00",
+            "2020-03-17 00:00:00.000",
+            "2020-04-01 12:00:00.000",
+        ],
         scale="tdb",
     )
     equatorial_coordinates = CartesianRepresentation(
@@ -223,7 +242,7 @@ def test_ephem_from_body_has_expected_properties(method, plane, FrameClass, rtol
     )
 
     earth = Ephem.from_body(Earth, epochs, plane=plane)
-    coordinates = earth.sample(method=method)
+    coordinates = earth.sample(interpolator=interpolator)
 
     assert earth.epochs is epochs
     assert_coordinates_allclose(coordinates, expected_coordinates, rtol=rtol)
@@ -250,7 +269,8 @@ def test_from_body_scalar_epoch_uses_reshaped_epochs():
 
 @mock.patch("poliastro.ephem.Horizons")
 @pytest.mark.parametrize(
-    "attractor,location_str", [(None, "@ssb"), (Earth, "500@399"), (Venus, "500@299")]
+    "attractor,location_str",
+    [(None, "@ssb"), (Earth, "500@399"), (Venus, "500@299")],
 )
 @pytest.mark.parametrize(
     "plane,refplane_str",
@@ -274,15 +294,24 @@ def test_ephem_from_horizons_calls_horizons_with_correct_parameters(
     expected_coordinates = CartesianRepresentation(
         [(1, 0, 0)] * u.au,
         xyz_axis=1,
-        differentials=CartesianDifferential([(0, 1, 0)] * (u.au / u.day), xyz_axis=1),
+        differentials=CartesianDifferential(
+            [(0, 1, 0)] * (u.au / u.day), xyz_axis=1
+        ),
     )
 
     ephem = Ephem.from_horizons(
-        unused_name, epochs, attractor=attractor, plane=plane, id_type=unused_id_type
+        unused_name,
+        epochs,
+        attractor=attractor,
+        plane=plane,
+        id_type=unused_id_type,
     )
 
     horizons_mock.assert_called_with(
-        id=unused_name, location=location_str, epochs=epochs.jd, id_type=unused_id_type
+        id=unused_name,
+        location=location_str,
+        epochs=epochs.jd,
+        id_type=unused_id_type,
     )
     horizons_mock().vectors.assert_called_once_with(refplane=refplane_str)
 
@@ -332,17 +361,17 @@ def test_from_orbit_scalar_epoch_uses_reshaped_epochs():
     v = [-3.457, 6.618, 2.533] * u.km / u.s
     orb = Orbit.from_vectors(Earth, r, v)
     expected_epochs = Time(["2020-01-02 12:00:00"])
-    epochs = expected_epochs[0]
+    epoch = expected_epochs[0]
 
     unused_plane = Planes.EARTH_EQUATOR
-    ephem = Ephem.from_orbit(orbit=orb, epochs=epochs, plane=unused_plane)
+    ephem = Ephem.from_orbit(orbit=orb, epochs=epoch, plane=unused_plane)
 
     assert ephem.epochs == expected_epochs
 
 
-@pytest.mark.parametrize("method", AVAILABLE_INTERPOLATION_METHODS)
+@pytest.mark.parametrize("interpolator", AVAILABLE_INTERPOLATORS)
 @pytest.mark.parametrize("rtol", [1e-7, 1e-5])
-def test_from_orbit_has_desired_properties(method, rtol):
+def test_from_orbit_has_desired_properties(interpolator, rtol):
     epochs = Time(
         [
             "2020-02-01 12:00:00",
