@@ -1,11 +1,7 @@
 import numpy as np
 import pytest
 from astropy import units as u
-from astropy.coordinates import (
-    CartesianRepresentation,
-    get_body_barycentric,
-    solar_system_ephemeris,
-)
+from astropy.coordinates import CartesianRepresentation, get_body_barycentric
 from astropy.tests.helper import assert_quantity_allclose
 from astropy.time import Time
 
@@ -82,16 +78,15 @@ def test_planetary_frames_have_proper_string_representations(body, frame):
     ],
 )
 def test_planetary_icrs_frame_is_just_translation(body, frame):
-    with solar_system_ephemeris.set("builtin"):
-        epoch = J2000
-        vector = CartesianRepresentation(x=100 * u.km, y=100 * u.km, z=100 * u.km)
-        vector_result = (
-            frame(vector, obstime=epoch)
-            .transform_to(ICRS())
-            .represent_as(CartesianRepresentation)
-        )
+    epoch = J2000
+    vector = CartesianRepresentation(x=100 * u.km, y=100 * u.km, z=100 * u.km)
+    vector_result = (
+        frame(vector, obstime=epoch)
+        .transform_to(ICRS())
+        .represent_as(CartesianRepresentation)
+    )
 
-        expected_result = get_body_barycentric(body.name, epoch) + vector
+    expected_result = get_body_barycentric(body.name, epoch) + vector
 
     assert_quantity_allclose(vector_result.xyz, expected_result.xyz)
 
@@ -111,17 +106,18 @@ def test_planetary_icrs_frame_is_just_translation(body, frame):
     ],
 )
 def test_icrs_body_position_to_planetary_frame_yields_zeros(body, frame):
-    with solar_system_ephemeris.set("builtin"):
-        epoch = J2000
-        vector = get_body_barycentric(body.name, epoch)
+    epoch = J2000
+    vector = get_body_barycentric(body.name, epoch)
 
-        vector_result = (
-            ICRS(vector)
-            .transform_to(frame(obstime=epoch))
-            .represent_as(CartesianRepresentation)
-        )
+    vector_result = (
+        ICRS(vector)
+        .transform_to(frame(obstime=epoch))
+        .represent_as(CartesianRepresentation)
+    )
 
-    assert_quantity_allclose(vector_result.xyz, [0, 0, 0] * u.km, atol=1e-7 * u.km)
+    assert_quantity_allclose(
+        vector_result.xyz, [0, 0, 0] * u.km, atol=1e-7 * u.km
+    )
 
 
 @pytest.mark.parametrize(
@@ -138,19 +134,26 @@ def test_icrs_body_position_to_planetary_frame_yields_zeros(body, frame):
         (Neptune, NeptuneFixed, NeptuneICRS),
     ],
 )
-def test_planetary_fixed_inertial_conversion(body, fixed_frame, inertial_frame):
-    with solar_system_ephemeris.set("builtin"):
-        epoch = J2000
-        fixed_position = fixed_frame(
-            0 * u.deg, 0 * u.deg, body.R, obstime=epoch, representation_type="spherical"
-        )
-        inertial_position = fixed_position.transform_to(inertial_frame(obstime=epoch))
-        assert_quantity_allclose(
-            fixed_position.spherical.distance, body.R, atol=1e-7 * u.km
-        )
-        assert_quantity_allclose(
-            inertial_position.spherical.distance, body.R, atol=1e-7 * u.km
-        )
+def test_planetary_fixed_inertial_conversion(
+    body, fixed_frame, inertial_frame
+):
+    epoch = J2000
+    fixed_position = fixed_frame(
+        0 * u.deg,
+        0 * u.deg,
+        body.R,
+        obstime=epoch,
+        representation_type="spherical",
+    )
+    inertial_position = fixed_position.transform_to(
+        inertial_frame(obstime=epoch)
+    )
+    assert_quantity_allclose(
+        fixed_position.spherical.distance, body.R, atol=1e-7 * u.km
+    )
+    assert_quantity_allclose(
+        inertial_position.spherical.distance, body.R, atol=1e-7 * u.km
+    )
 
 
 @pytest.mark.parametrize(
@@ -167,19 +170,24 @@ def test_planetary_fixed_inertial_conversion(body, fixed_frame, inertial_frame):
         (Neptune, NeptuneFixed, NeptuneICRS),
     ],
 )
-def test_planetary_inertial_fixed_conversion(body, fixed_frame, inertial_frame):
-    with solar_system_ephemeris.set("builtin"):
-        epoch = J2000
-        inertial_position = inertial_frame(
-            0 * u.deg, 0 * u.deg, body.R, obstime=epoch, representation_type="spherical"
-        )
-        fixed_position = inertial_position.transform_to(fixed_frame(obstime=epoch))
-        assert_quantity_allclose(
-            fixed_position.spherical.distance, body.R, atol=1e-7 * u.km
-        )
-        assert_quantity_allclose(
-            inertial_position.spherical.distance, body.R, atol=1e-7 * u.km
-        )
+def test_planetary_inertial_fixed_conversion(
+    body, fixed_frame, inertial_frame
+):
+    epoch = J2000
+    inertial_position = inertial_frame(
+        0 * u.deg,
+        0 * u.deg,
+        body.R,
+        obstime=epoch,
+        representation_type="spherical",
+    )
+    fixed_position = inertial_position.transform_to(fixed_frame(obstime=epoch))
+    assert_quantity_allclose(
+        fixed_position.spherical.distance, body.R, atol=1e-7 * u.km
+    )
+    assert_quantity_allclose(
+        inertial_position.spherical.distance, body.R, atol=1e-7 * u.km
+    )
 
 
 @pytest.mark.parametrize(
@@ -196,28 +204,29 @@ def test_planetary_inertial_fixed_conversion(body, fixed_frame, inertial_frame):
         (Neptune, NeptuneFixed, NeptuneICRS),
     ],
 )
-def test_planetary_inertial_roundtrip_vector(body, fixed_frame, inertial_frame):
-    with solar_system_ephemeris.set("builtin"):
-        epoch = J2000
-        sampling_time = 10 * u.s
-        fixed_position = fixed_frame(
-            np.broadcast_to(0 * u.deg, (1000,), subok=True),
-            np.broadcast_to(0 * u.deg, (1000,), subok=True),
-            np.broadcast_to(body.R, (1000,), subok=True),
-            representation_type="spherical",
-            obstime=epoch + np.arange(1000) * sampling_time,
-        )
-        inertial_position = fixed_position.transform_to(
-            inertial_frame(obstime=epoch + np.arange(1000) * sampling_time)
-        )
-        fixed_position_roundtrip = inertial_position.transform_to(
-            fixed_frame(obstime=epoch + np.arange(1000) * sampling_time)
-        )
-        assert_quantity_allclose(
-            fixed_position.cartesian.xyz,
-            fixed_position_roundtrip.cartesian.xyz,
-            atol=1e-7 * u.km,
-        )
+def test_planetary_inertial_roundtrip_vector(
+    body, fixed_frame, inertial_frame
+):
+    epoch = J2000
+    sampling_time = 10 * u.s
+    fixed_position = fixed_frame(
+        np.broadcast_to(0 * u.deg, (1000,), subok=True),
+        np.broadcast_to(0 * u.deg, (1000,), subok=True),
+        np.broadcast_to(body.R, (1000,), subok=True),
+        representation_type="spherical",
+        obstime=epoch + np.arange(1000) * sampling_time,
+    )
+    inertial_position = fixed_position.transform_to(
+        inertial_frame(obstime=epoch + np.arange(1000) * sampling_time)
+    )
+    fixed_position_roundtrip = inertial_position.transform_to(
+        fixed_frame(obstime=epoch + np.arange(1000) * sampling_time)
+    )
+    assert_quantity_allclose(
+        fixed_position.cartesian.xyz,
+        fixed_position_roundtrip.cartesian.xyz,
+        atol=1e-7 * u.km,
+    )
 
 
 def test_round_trip_from_GeocentricSolarEcliptic_gives_same_results():
@@ -240,7 +249,9 @@ def test_GeocentricSolarEcliptic_against_data():
 def test_GeocentricSolarEcliptic_raises_error_nonscalar_obstime():
     with pytest.raises(ValueError) as excinfo:
         gcrs = GCRS(ra="02h31m49.09s", dec="+89d15m50.8s", distance=200 * u.km)
-        gcrs.transform_to(GeocentricSolarEcliptic(obstime=Time(["J3200", "J2000"])))
+        gcrs.transform_to(
+            GeocentricSolarEcliptic(obstime=Time(["J3200", "J2000"]))
+        )
     assert (
         "To perform this transformation the "
         "obstime Attribute must be a scalar." in str(excinfo.value)
@@ -251,7 +262,11 @@ def test_GeocentricSolarEcliptic_raises_error_nonscalar_obstime():
     "body, fixed_frame, radecW",
     [
         (Sun, SunFixed, (286.13 * u.deg, 63.87 * u.deg, 84.176 * u.deg)),
-        (Mercury, MercuryFixed, (281.0103 * u.deg, 61.45 * u.deg, 329.5999488 * u.deg)),
+        (
+            Mercury,
+            MercuryFixed,
+            (281.0103 * u.deg, 61.45 * u.deg, 329.5999488 * u.deg),
+        ),
         (Venus, VenusFixed, (272.76 * u.deg, 67.16 * u.deg, 160.2 * u.deg)),
         (
             Mars,
@@ -264,7 +279,11 @@ def test_GeocentricSolarEcliptic_raises_error_nonscalar_obstime():
             (268.05720404 * u.deg, 64.49580995 * u.deg, 284.95 * u.deg),
         ),
         (Saturn, SaturnFixed, (40.589 * u.deg, 83.537 * u.deg, 38.9 * u.deg)),
-        (Uranus, UranusFixed, (257.311 * u.deg, -15.175 * u.deg, 203.81 * u.deg)),
+        (
+            Uranus,
+            UranusFixed,
+            (257.311 * u.deg, -15.175 * u.deg, 203.81 * u.deg),
+        ),
         (
             Neptune,
             NeptuneFixed,
@@ -281,10 +300,16 @@ def test_GeocentricSolarEcliptic_raises_error_nonscalar_obstime():
         ),
     ],
 )
-def test_fixed_frame_calculation_gives_expected_result(body, fixed_frame, radecW):
+def test_fixed_frame_calculation_gives_expected_result(
+    body, fixed_frame, radecW
+):
     epoch = J2000
     fixed_position = fixed_frame(
-        0 * u.deg, 0 * u.deg, body.R, obstime=epoch, representation_type="spherical"
+        0 * u.deg,
+        0 * u.deg,
+        body.R,
+        obstime=epoch,
+        representation_type="spherical",
     )
 
     assert_quantity_allclose(
