@@ -14,7 +14,9 @@ def test_plot_solar_system_has_expected_number_of_orbits(outer, expected):
     "use_3d, plotter_class", [(True, OrbitPlotter3D), (False, OrbitPlotter2D)]
 )
 def test_plot_solar_system_uses_expected_orbitplotter(use_3d, plotter_class):
-    assert isinstance(plot_solar_system(use_3d=use_3d, interactive=True), plotter_class)
+    assert isinstance(
+        plot_solar_system(use_3d=use_3d, interactive=True), plotter_class
+    )
 
 
 def test_plot_solar_system_raises_error_if_use_3d_and_non_interactive():
