@@ -12,7 +12,9 @@ def test_porkchop_plotting():
 
     launch_span = time_range("2005-04-30", end="2005-10-07")
     arrival_span = time_range("2005-11-16", end="2006-12-21")
-    porkchop_plot = PorkchopPlotter(Earth, Mars, launch_span, arrival_span, ax=ax)
+    porkchop_plot = PorkchopPlotter(
+        Earth, Mars, launch_span, arrival_span, ax=ax
+    )
     dv_dpt, dv_arr, c3dpt, c3arr, tof = porkchop_plot.porkchop()
 
     return fig
