@@ -10,15 +10,7 @@ from pytest import approx
 from poliastro.bodies import Earth, Moon, Sun
 from poliastro.constants import J2000
 from poliastro.core.elements import rv2coe
-from poliastro.core.propagation import (
-    danby_coe,
-    func_twobody,
-    gooding_coe,
-    markley_coe,
-    mikkola_coe,
-    pimienta_coe,
-)
-from poliastro.core.propagation.farnocchia import farnocchia_coe
+from poliastro.core.propagation import func_twobody
 from poliastro.examples import iss
 from poliastro.frames import Planes
 from poliastro.twobody import Orbit
@@ -27,15 +19,13 @@ from poliastro.twobody.propagation import (
     ELLIPTIC_PROPAGATORS,
     HYPERBOLIC_PROPAGATORS,
     PARABOLIC_PROPAGATORS,
-    cowell,
-    danby,
-    farnocchia,
-    gooding,
-    markley,
-    mikkola,
-    pimienta,
-    propagate,
-    vallado,
+    CowellPropagator,
+    DanbyPropagator,
+    FarnocchiaPropagator,
+    GoodingPropagator,
+    MarkleyPropagator,
+    RecseriesPropagator,
+    ValladoPropagator,
 )
 from poliastro.util import norm
 
@@ -52,9 +42,11 @@ def halley():
 @pytest.mark.parametrize("ecc", [0.9, 0.99, 0.999, 0.9999, 0.99999])
 @pytest.mark.parametrize("propagator", ELLIPTIC_PROPAGATORS)
 def test_elliptic_near_parabolic(ecc, propagator):
-    # 'kepler fails if really close to parabolic'. Refer to issue #714.
-    if propagator in [vallado] and ecc > 0.99:
-        pytest.xfail()
+    rtol = 1e-7
+    if propagator in (RecseriesPropagator, ValladoPropagator):
+        rtol = 1e-6
+    if propagator is ValladoPropagator and ecc >= 0.99999:
+        rtol = 1e-5
 
     _a = 0.0 * u.rad
     tof = 1.0 * u.min
@@ -68,20 +60,16 @@ def test_elliptic_near_parabolic(ecc, propagator):
         nu=1.0 * u.rad,
     )
 
-    ss_cowell = ss0.propagate(tof, method=cowell)
-    ss_propagator = ss0.propagate(tof, method=propagator)
+    ss_cowell = ss0.propagate(tof, method=CowellPropagator())
+    ss_propagator = ss0.propagate(tof, method=propagator())
 
-    assert_quantity_allclose(ss_propagator.r, ss_cowell.r)
-    assert_quantity_allclose(ss_propagator.v, ss_cowell.v)
+    assert_quantity_allclose(ss_propagator.r, ss_cowell.r, rtol=rtol)
+    assert_quantity_allclose(ss_propagator.v, ss_cowell.v, rtol=rtol)
 
 
 @pytest.mark.parametrize("ecc", [1.0001, 1.001, 1.01, 1.1])
 @pytest.mark.parametrize("propagator", HYPERBOLIC_PROPAGATORS)
 def test_hyperbolic_near_parabolic(ecc, propagator):
-    # Still not implemented. Refer to issue #714.
-    if propagator in [pimienta, gooding]:
-        pytest.skip()
-
     _a = 0.0 * u.rad
     tof = 1.0 * u.min
     ss0 = Orbit.from_classical(
@@ -94,22 +82,23 @@ def test_hyperbolic_near_parabolic(ecc, propagator):
         nu=1.0 * u.rad,
     )
 
-    ss_cowell = ss0.propagate(tof, method=cowell)
-    ss_propagator = ss0.propagate(tof, method=propagator)
+    ss_cowell = ss0.propagate(tof, method=CowellPropagator())
+    ss_propagator = ss0.propagate(tof, method=propagator())
 
     assert_quantity_allclose(ss_propagator.r, ss_cowell.r)
     assert_quantity_allclose(ss_propagator.v, ss_cowell.v)
 
 
-@pytest.mark.parametrize("propagator", [markley])
-def test_near_equatorial(propagator):
+@pytest.mark.parametrize("method", [MarkleyPropagator()])
+def test_near_equatorial(method):
+    # TODO: Extend to other propagators?
     r = [8.0e3, 1.0e3, 0.0] * u.km
     v = [-0.5, -0.5, 0.0001] * u.km / u.s
     tof = 1.0 * u.h
     ss0 = Orbit.from_vectors(Earth, r, v)
 
-    ss_cowell = ss0.propagate(tof, method=cowell)
-    ss_propagator = ss0.propagate(tof, method=propagator)
+    ss_cowell = ss0.propagate(tof, method=CowellPropagator())
+    ss_propagator = ss0.propagate(tof, method=method)
 
     assert_quantity_allclose(ss_propagator.r, ss_cowell.r, rtol=1e-4)
     assert_quantity_allclose(ss_propagator.v, ss_cowell.v, rtol=1e-4)
@@ -125,7 +114,7 @@ def test_propagation(propagator):
 
     ss0 = Orbit.from_vectors(Earth, r0, v0)
     tof = 40 * u.min
-    ss1 = ss0.propagate(tof, method=propagator)
+    ss1 = ss0.propagate(tof, method=propagator())
 
     r, v = ss1.rv()
 
@@ -161,7 +150,9 @@ def test_propagating_to_certain_nu_is_correct():
     for nu in np.random.uniform(low=-np.pi, high=np.pi, size=10):
         elliptic = elliptic.propagate_to_anomaly(nu * u.rad)
         r, _ = elliptic.rv()
-        assert_quantity_allclose(norm(r), a * (1.0 - ecc ** 2) / (1 + ecc * np.cos(nu)))
+        assert_quantity_allclose(
+            norm(r), a * (1.0 - ecc**2) / (1 + ecc * np.cos(nu))
+        )
 
 
 def test_propagate_to_anomaly_in_the_past_fails_for_open_orbits():
@@ -169,7 +160,9 @@ def test_propagate_to_anomaly_in_the_past_fails_for_open_orbits():
     v0 = [0, 15, 0] * u.km / u.s
     orb = Orbit.from_vectors(Earth, r0, v0)
 
-    with pytest.raises(ValueError, match="True anomaly -0.02 rad not reachable"):
+    with pytest.raises(
+        ValueError, match="True anomaly -0.02 rad not reachable"
+    ):
         orb.propagate_to_anomaly(orb.nu - 1 * u.deg)
 
 
@@ -209,24 +202,20 @@ def test_propagation_hyperbolic():
 @pytest.mark.parametrize("propagator", PARABOLIC_PROPAGATORS)
 def test_propagation_parabolic(propagator):
     # Example from Howard Curtis (3rd edition), section 3.5, problem 3.15
-    # TODO: add parabolic solver in some parabolic propagators, refer to #417
-    if propagator in [mikkola, gooding]:
-        pytest.skip()
-
     p = 2.0 * 6600 * u.km
     _a = 0.0 * u.deg
     orbit = Orbit.parabolic(Earth, p, _a, _a, _a, _a)
-    orbit = orbit.propagate(0.8897 / 2.0 * u.h, method=propagator)
+    orbit = orbit.propagate(0.8897 / 2.0 * u.h, method=propagator())
 
     _, _, _, _, _, nu0 = rv2coe(
-        Earth.k.to(u.km ** 3 / u.s ** 2).value,
+        Earth.k.to(u.km**3 / u.s**2).value,
         orbit.r.to(u.km).value,
         orbit.v.to(u.km / u.s).value,
     )
     assert_quantity_allclose(nu0, np.deg2rad(90.0), rtol=1e-4)
 
     orbit = Orbit.parabolic(Earth, p, _a, _a, _a, _a)
-    orbit = orbit.propagate(36.0 * u.h, method=propagator)
+    orbit = orbit.propagate(36.0 * u.h, method=propagator())
     assert_quantity_allclose(norm(orbit.r), 304700.0 * u.km, rtol=1e-4)
 
 
@@ -277,7 +266,9 @@ def test_apply_zero_maneuver_returns_equal_state():
     dv = [0, 0, 0] * u.km / u.s
     orbit_new = ss.apply_maneuver([(dt, dv)])
     assert_allclose(orbit_new.r.to(u.km).value, ss.r.to(u.km).value)
-    assert_allclose(orbit_new.v.to(u.km / u.s).value, ss.v.to(u.km / u.s).value)
+    assert_allclose(
+        orbit_new.v.to(u.km / u.s).value, ss.v.to(u.km / u.s).value
+    )
 
 
 def test_cowell_propagation_with_zero_acceleration_equals_kepler():
@@ -292,10 +283,11 @@ def test_cowell_propagation_with_zero_acceleration_equals_kepler():
     expected_r = np.array([-4219.7527, 4363.0292, -3958.7666]) * u.km
     expected_v = np.array([3.689866, -1.916735, -6.112511]) * u.km / u.s
 
-    r, v = cowell(Earth.k, orbit.r, orbit.v, tofs)
+    method = CowellPropagator()
+    rrs, vvs = method.propagate_many(orbit._state, tofs)
 
-    assert_quantity_allclose(r[0], expected_r, rtol=1e-5)
-    assert_quantity_allclose(v[0], expected_v, rtol=1e-4)
+    assert_quantity_allclose(rrs[0], expected_r, rtol=1e-5)
+    assert_quantity_allclose(vvs[0], expected_v, rtol=1e-4)
 
 
 def test_cowell_propagation_circle_to_circle():
@@ -317,16 +309,17 @@ def test_cowell_propagation_circle_to_circle():
     ss = Orbit.circular(Earth, 500 * u.km)
     tofs = [20] * ss.period
 
-    r, v = cowell(Earth.k, ss.r, ss.v, tofs, f=f)
+    method = CowellPropagator(f=f)
+    rrs, vvs = method.propagate_many(ss._state, tofs)
 
-    ss_final = Orbit.from_vectors(Earth, r[0], v[0])
+    ss_final = Orbit.from_vectors(Earth, rrs[0], vvs[0])
 
     da_a0 = (ss_final.a - ss.a) / ss.a
     dv_v0 = abs(norm(ss_final.v) - norm(ss.v)) / norm(ss.v)
     assert_quantity_allclose(da_a0, 2 * dv_v0, rtol=1e-2)
 
     dv = abs(norm(ss_final.v) - norm(ss.v))
-    accel_dt = accel * u.km / u.s ** 2 * tofs[0]
+    accel_dt = accel * u.km / u.s**2 * tofs[0]
     assert_quantity_allclose(dv, accel_dt, rtol=1e-2)
 
 
@@ -353,12 +346,15 @@ def test_propagate_to_date_has_proper_epoch():
 
 
 @pytest.mark.filterwarnings("ignore::erfa.core.ErfaWarning")
-@pytest.mark.parametrize("propagator", [danby, markley, gooding])
-def test_propagate_long_times_keeps_geometry(propagator):
+@pytest.mark.parametrize(
+    "method", [DanbyPropagator(), MarkleyPropagator(), GoodingPropagator()]
+)
+def test_propagate_long_times_keeps_geometry(method):
+    # TODO: Extend to other propagators?
     # See https://github.com/poliastro/poliastro/issues/265
     time_of_flight = 100 * u.year
 
-    res = iss.propagate(time_of_flight, method=propagator)
+    res = iss.propagate(time_of_flight, method=method)
 
     assert_quantity_allclose(iss.a, res.a)
     assert_quantity_allclose(iss.ecc, res.ecc)
@@ -374,17 +370,21 @@ def test_propagate_long_times_keeps_geometry(propagator):
 @pytest.mark.filterwarnings("ignore::erfa.core.ErfaWarning")
 def test_long_propagations_vallado_agrees_farnocchia():
     tof = 100 * u.year
-    r_mm, v_mm = iss.propagate(tof, method=farnocchia).rv()
-    r_k, v_k = iss.propagate(tof, method=vallado).rv()
+    r_mm, v_mm = iss.propagate(tof, method=FarnocchiaPropagator()).rv()
+    r_k, v_k = iss.propagate(tof, method=ValladoPropagator()).rv()
     assert_quantity_allclose(r_mm, r_k)
     assert_quantity_allclose(v_mm, v_k)
 
-    r_halleys = [-9018878.63569932, -94116054.79839276, 22619058.69943215]  # km
+    r_halleys = [
+        -9018878.63569932,
+        -94116054.79839276,
+        22619058.69943215,
+    ]  # km
     v_halleys = [-49.95092305, -12.94843055, -4.29251577]  # km/s
     halleys = Orbit.from_vectors(Sun, r_halleys * u.km, v_halleys * u.km / u.s)
 
-    r_mm, v_mm = halleys.propagate(tof, method=farnocchia).rv()
-    r_k, v_k = halleys.propagate(tof, method=vallado).rv()
+    r_mm, v_mm = halleys.propagate(tof, method=FarnocchiaPropagator()).rv()
+    r_k, v_k = halleys.propagate(tof, method=ValladoPropagator()).rv()
     assert_quantity_allclose(r_mm, r_k)
     assert_quantity_allclose(v_mm, v_k)
 
@@ -395,10 +395,11 @@ def test_farnocchia_propagation_very_high_ecc_does_not_fail():
     v = np.array([5021.38, -2900.7, 1000.354]) << u.km / u.s
     orbit = Orbit.from_vectors(Earth, r, v, epoch=time.Time("2020-01-01"))
 
-    tofs = [74] << u.s  # tof = 74s and above is the critical region.
-    coords = propagate(orbit, tofs)
+    tofs = [74] << u.s  # tof = 74s and above is the critical region
+    method = FarnocchiaPropagator()
+    coords, _ = method.propagate_many(orbit._state, tofs)
 
-    assert not np.isnan(coords.get_xyz()).any()
+    assert not np.isnan(coords).any()
 
 
 @st.composite
@@ -416,13 +417,17 @@ def with_units(draw, elements, unit):
         unit=u.year,
     )
 )
-@pytest.mark.parametrize("method", [farnocchia, vallado])
+@pytest.mark.parametrize(
+    "method", [FarnocchiaPropagator(), ValladoPropagator()]
+)
 def test_long_propagation_preserves_orbit_elements(tof, method, halley):
     expected_slow_classical = halley.classical()[:-1]
 
     slow_classical = halley.propagate(tof, method=method).classical()[:-1]
 
-    for element, expected_element in zip(slow_classical, expected_slow_classical):
+    for element, expected_element in zip(
+        slow_classical, expected_slow_classical
+    ):
         assert_quantity_allclose(element, expected_element)
 
 
@@ -438,9 +443,9 @@ def test_propagation_sets_proper_epoch():
     assert propagated.epoch == expected_epoch
 
 
-def test_sample_custom_body_raises_warning_and_returns_coords():
+def test_sample_around_moon_works():
     # See https://github.com/poliastro/poliastro/issues/649
-    orbit = Orbit.circular(Moon, 100 * u.km)
+    orbit = Orbit.circular(Moon, 100 << u.km)
 
     coords = orbit.sample(10)
 
@@ -448,35 +453,12 @@ def test_sample_custom_body_raises_warning_and_returns_coords():
     assert len(coords) == 10
 
 
-def test_propagation_custom_body_works():
+def test_propagate_around_moon_works():
     # See https://github.com/poliastro/poliastro/issues/649
-    orbit = Orbit.circular(Moon, 100 * u.km)
-    orbit.propagate(1 * u.h)
+    orbit = Orbit.circular(Moon, 100 << u.km)
+    new_orbit = orbit.propagate(1 << u.h)
 
-
-@pytest.mark.parametrize(
-    "propagator_coe",
-    [danby_coe, markley_coe, pimienta_coe, mikkola_coe, farnocchia_coe, gooding_coe],
-)
-def test_propagate_with_coe(propagator_coe):
-
-    period = iss.period
-    a, ecc, inc, raan, argp, nu = iss.classical()
-    p = a * (1 - ecc ** 2)
-
-    # Delete the units
-    p = p.to_value(u.km)
-    ecc = ecc.value
-    period = period.to_value(u.s)
-    inc = inc.to_value(u.rad)
-    raan = raan.to_value(u.rad)
-    argp = argp.to_value(u.rad)
-    nu = nu.to_value(u.rad)
-    k = iss.attractor.k.to_value(u.km ** 3 / u.s ** 2)
-
-    nu_final = propagator_coe(k, p, ecc, inc, raan, argp, nu, period)
-
-    assert_quantity_allclose(nu_final, nu)
+    assert_quantity_allclose((new_orbit.epoch - orbit.epoch).to(u.h), 1 << u.h)
 
 
 @pytest.mark.parametrize("propagator", ALL_PROPAGATORS)
@@ -485,29 +467,10 @@ def test_propagator_with_zero_eccentricity(propagator):
     altitude = 300 * u.km
     orbit = Orbit.circular(attractor, altitude)
     time_of_flight = 50 * u.s
-    res = orbit.propagate(time_of_flight, method=propagator)
+    res = orbit.propagate(time_of_flight, method=propagator())
 
     assert_quantity_allclose(orbit.a, res.a)
     assert_quantity_allclose(orbit.ecc, res.ecc, atol=1e-15)
     assert_quantity_allclose(orbit.inc, res.inc)
     assert_quantity_allclose(orbit.raan, res.raan)
     assert_quantity_allclose(orbit.argp, res.argp)
-
-
-@pytest.mark.parametrize("propagator", ALL_PROPAGATORS)
-def test_after_propagation_r_and_v_dimensions(propagator):
-    r0 = [111.340, -228.343, 2413.423] * u.km
-    v0 = [-5.64305, 4.30333, 2.42879] * u.km / u.s
-    tof = time.TimeDelta(50 * u.s)
-    orbit = Orbit.from_vectors(Earth, r0, v0)
-
-    rr, vv = propagator(
-        orbit.attractor.k,
-        orbit.r,
-        orbit.v,
-        tof.reshape(-1).to(u.s),
-        rtol=1e-10,
-    )
-
-    assert rr.ndim == 2
-    assert vv.ndim == 2
